@@ -12,7 +12,7 @@ use URI::Escape 0 qw/uri_escape/;
 
 BEGIN {
 	$RDF::Query::Client::AUTHORITY = 'cpan:TOBYINK';
-	$RDF::Query::Client::VERSION   = '0.109';
+	$RDF::Query::Client::VERSION   = '0.112';
 }
 
 use namespace::clean;
@@ -154,8 +154,8 @@ sub useragent
 	unless (defined $self->{useragent})
 	{
 		my $accept = join q{, },
-			'application/sparql-results+json',
-			'application/sparql-results+xml;q=0.9',
+			'application/sparql-results+xml',
+			'application/sparql-results+json;q=0.9',
 			'application/rdf+xml',
 			'application/x-turtle',
 			'text/turtle';
@@ -270,13 +270,12 @@ sub _create_iterator
 		return;
 	}
 	
-	if ($response->content_type eq 'application/sparql-results+xml'
-	or  $response->content_type eq 'application/sparql-results+json')
+	if ($response->content_type =~ /sparql.results/)
 	{
 		local $@ = undef;
 		my $iterator = eval
 		{
-			if ($response->content_type eq 'application/sparql-results+json')
+			if ($response->content_type =~ /json/)
 				{ RDF::Trine::Iterator->from_json($response->decoded_content); }
 			else
 				{ RDF::Trine::Iterator->from_string($response->decoded_content); }
@@ -309,6 +308,21 @@ sub _create_iterator
 
 __END__
 
+=pod
+
+=encoding utf8
+
+=begin stopwords
+
+'sparql'
+application/sparql-query
+application/sparql-update
+application/x-www-form-urlencoded
+rel
+WebID
+
+=end stopwords
+
 =head1 NAME
 
 RDF::Query::Client - get data from W3C SPARQL Protocol 1.0 servers
@@ -391,7 +405,7 @@ iterator if called in list context.
 
 =item C<< discover_execute( $resource_uri, \%opts ) >>
 
-Experimental feature. Discovers a SPARQL endpoint relevent to $resource_uri
+Experimental feature. Discovers a SPARQL endpoint relevant to $resource_uri
 and then calls C<< $query->execute >> against that. Uses an LRDD-like
 method to discover the endpoint. If you're publishing data and want people
 to be able to find your SPARQL endpoint automatically, the easiest way is to
@@ -455,11 +469,11 @@ L<https://rt.cpan.org/Dist/Display.html?Queue=RDF-Query-Client>.
 
 =item * L<LWP::UserAgent>
 
-=item * http://www.w3.org/TR/rdf-sparql-protocol/
+=item * L<http://www.w3.org/TR/rdf-sparql-protocol/>
 
-=item * http://www.w3.org/TR/rdf-sparql-query/
+=item * L<http://www.w3.org/TR/rdf-sparql-query/>
 
-=item * http://www.perlrdf.org/
+=item * L<http://www.perlrdf.org/>
 
 =back
 
@@ -469,7 +483,7 @@ Toby Inkster, E<lt>tobyink@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Toby Inkster
+Copyright (C) 2009-2013 by Toby Inkster
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
